==> open-xchange-imageconverter-client_7.10.3.orig.tar.bz2: open-xchange-imageconverter-client-7.10.3/com.openexchange.imageconverter.client/src/com/openexchange/imageconverter/client/ImageConverterApiProvider.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.imageconverter.client;

import java.net.HttpURLConnection;

import javax.net.ssl.HttpsURLConnection;
import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSocketFactory;

import org.glassfish.jersey.client.HttpUrlConnectorProvider;

import com.openexchange.annotation.NonNull;
import com.openexchange.annotation.Nullable;
import com.openexchange.auth.Credentials;
import com.openexchange.imageconverter.client.generated.invoker.ApiClient;
import com.openexchange.imageconverter.client.generated.modules.ImageConverterApi;

/**
 * {@link ImageConverterAPIProvider}
 *
 * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
 * @since v7.10.0
 */
class ImageConverterApiProvider {

    // Default connection timeout of 60s
    final private static int DEFAULT_CONNECT_TIMEOUT_MILLIS = 60 * 1000;

    /**
     * Unused
     */
    @SuppressWarnings("unused")
    private ImageConverterApiProvider() {
        // Unused
        super();
        m_apiClient = null;
    }

    /**
     * Initializes a new {@link ImageConverterAPIProvider}.
     * @param imageConverterRemoteValidator
     */
    ImageConverterApiProvider(
        @NonNull final ImageConverterClientConfig imageConverterClientConfig,
        @Nullable final SSLSocketFactory sslSocketFactory,
        @Nullable final SSLContext sslContext) {

        super();

        // Using own http(s) connection factory to use given SSLSocketfactory;
        // since this SSLSocketfactory might be overridden by the Jersey impl. using
        // the configured SSLContext, the originating SSLContext needs to be
        // provided y the used ClientBuilder as well.
        m_apiClient = new ApiClient(
            (clientConfig) -> {
                return (null != sslSocketFactory) ?
                    clientConfig.connectorProvider(
                        new HttpUrlConnectorProvider().connectionFactory((url) -> {
                            final HttpURLConnection httpConnection = (HttpURLConnection) url.openConnection();

                            if (httpConnection instanceof HttpsURLConnection) {
                                ((HttpsURLConnection) httpConnection).setSSLSocketFactory(sslSocketFactory);
                            }

                            return httpConnection;
                        })) :
                            clientConfig;
            },
            (clientBuilder) -> {
                return (null != sslContext) ?
                    clientBuilder.sslContext(sslContext) :
                        clientBuilder;
            });

       implConfigure(imageConverterClientConfig);
    }

    /**
     * @return
     */
    ImageConverterApi acquire() {
        final ApiClient apiClient = m_apiClient;

        if (null != apiClient) {
            final Credentials credentials = m_credentials;

            if (null != credentials) {
                apiClient.setUsername(credentials.getLogin());
                apiClient.setPassword(credentials.getPassword());
            }

            return new ImageConverterApi(m_apiClient);
        }

        return null;
    }

    /**
     * @param apiInstance
     */
    public void release(ImageConverterApi apiInstance) {
        // nothing to be done here
    }

    /**
     * @param imageConverterClientConfig
     */
    public void updateConfiguration(@NonNull final ImageConverterClientConfig imageConverterClientConfig) {
        implConfigure(imageConverterClientConfig);
    }

    /**
     * @param credentials
     */
    public void setCredentials(@NonNull final Credentials credentials) {
        m_credentials = credentials;
    }

    // - Implementation --------------------------------------------------------

    private void implConfigure(@NonNull final ImageConverterClientConfig imageConverterClientConfig) {
        final ApiClient apiClient = m_apiClient;

        if (null != apiClient) {
            apiClient.setBasePath(imageConverterClientConfig.getImageConverterServerURL().toString());
            apiClient.setTempFolderPath(imageConverterClientConfig.getSpoolDir().getAbsolutePath());
            apiClient.setConnectTimeout(DEFAULT_CONNECT_TIMEOUT_MILLIS);
        }
    }


    // - Members ---------------------------------------------------------------

    volatile private ApiClient m_apiClient;

    volatile private Credentials m_credentials;
}

==> open-xchange-imageconverter-client_7.10.5.orig.tar.bz2: open-xchange-imageconverter-client-7.10.5/com.openexchange.imageconverter.client/src/com/openexchange/imageconverter/client/ImageConverterApiProvider.java <==
/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */



package com.openexchange.imageconverter.client;

import java.net.HttpURLConnection;
import javax.net.ssl.HttpsURLConnection;
import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSocketFactory;
import org.glassfish.jersey.client.HttpUrlConnectorProvider;
import com.openexchange.annotation.NonNull;
import com.openexchange.annotation.Nullable;
import com.openexchange.auth.Credentials;
import com.openexchange.imageconverter.client.generated.invoker.ApiClient;
import com.openexchange.imageconverter.client.generated.modules.ImageConverterApi;

/**
 * {@link ImageConverterAPIProvider}
 *
 * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
 * @since v7.10.0
 */
class ImageConverterApiProvider {

    // Default connection timeout of 10s
    final private static int DEFAULT_CONNECT_TIMEOUT_MILLIS = 10 * 1000;

    // Default read timeout of 60s
    final private static int DEFAULT_READ_TIMEOUT_MILLIS = 60 * 1000;

    /**
     * Unused
     */
    @SuppressWarnings("unused")
    private ImageConverterApiProvider() {
        // Unused
        super();
        m_apiClient = null;
    }

    /**
     * Initializes a new {@link ImageConverterAPIProvider}.
     * @param imageConverterRemoteValidator
     */
    ImageConverterApiProvider(
        @NonNull final ImageConverterClientConfig imageConverterClientConfig,
        @Nullable final SSLSocketFactory sslSocketFactory,
        @Nullable final SSLContext sslContext) {

        super();

        // Using own http(s) connection factory to use given SSLSocketfactory;
        // since this SSLSocketfactory might be overridden by the Jersey impl. using
        // the configured SSLContext, the originating SSLContext needs to be
        // provided y the used ClientBuilder as well.
        m_apiClient = new ApiClient(
            (clientConfig) -> {
                return (null != sslSocketFactory) ?
                    clientConfig.connectorProvider(
                        new HttpUrlConnectorProvider().connectionFactory((url) -> {
                            final HttpURLConnection httpConnection = (HttpURLConnection) url.openConnection();

                            if (httpConnection instanceof HttpsURLConnection) {
                                ((HttpsURLConnection) httpConnection).setSSLSocketFactory(sslSocketFactory);
                            }

                            return httpConnection;
                        })) :
                            clientConfig;
            },
            (clientBuilder) -> {
                return (null != sslContext) ?
                    clientBuilder.sslContext(sslContext) :
                        clientBuilder;
            });

       implConfigure(imageConverterClientConfig);
    }

    /**
     * @return
     */
    ImageConverterApi acquire() {
        final ApiClient apiClient = m_apiClient;

        if (null != apiClient) {
            final Credentials credentials = m_credentials;

            if (null != credentials) {
                apiClient.setUsername(credentials.getLogin());
                apiClient.setPassword(credentials.getPassword());
            }

            return new ImageConverterApi(m_apiClient);
        }

        return null;
    }

    /**
     * @param apiInstance
     */
    public void release(ImageConverterApi apiInstance) {
        // nothing to be done here
    }

    /**
     * @param imageConverterClientConfig
     */
    public void updateConfiguration(@NonNull final ImageConverterClientConfig imageConverterClientConfig) {
        implConfigure(imageConverterClientConfig);
    }

    /**
     * @param credentials
     */
    public void setCredentials(@NonNull final Credentials credentials) {
        m_credentials = credentials;
    }

    // - Implementation --------------------------------------------------------

    private void implConfigure(@NonNull final ImageConverterClientConfig imageConverterClientConfig) {
        final ApiClient apiClient = m_apiClient;

        if (null != apiClient) {
            apiClient.setBasePath(imageConverterClientConfig.getImageConverterServerURL().toString());
            apiClient.setTempFolderPath(imageConverterClientConfig.getSpoolDir().getAbsolutePath());
            apiClient.setConnectTimeout(DEFAULT_CONNECT_TIMEOUT_MILLIS);
            apiClient.setReadTimeout(DEFAULT_READ_TIMEOUT_MILLIS);
        }
    }


    // - Members ---------------------------------------------------------------

    volatile private ApiClient m_apiClient;

    volatile private Credentials m_credentials;
}
